summaryrefslogtreecommitdiff
path: root/gdb/corelow.c
diff options
context:
space:
mode:
authorPedro Alves <palves@redhat.com>2012-05-24 16:39:02 +0000
committerPedro Alves <palves@redhat.com>2012-05-24 16:39:02 +0000
commit906c2dc64fa6eeb6723219a58495036be6ba18c6 (patch)
treed7d63bb729d4f26639fbd92f44f2374d986b3b31 /gdb/corelow.c
parent7189cc1aaca27137d2ce6e4a01d423a0e97853cb (diff)
downloadgdb-906c2dc64fa6eeb6723219a58495036be6ba18c6.tar.gz
gdb/
2012-05-24 Pedro Alves <palves@redhat.com> PR gdb/7205 Replace target_signal with gdb_signal throughout. gdb/gdbserver/ 2012-05-24 Pedro Alves <palves@redhat.com> PR gdb/7205 Replace target_signal with gdb_signal throughout. include/gdb/ 2012-05-24 Pedro Alves <palves@redhat.com> PR gdb/7205 Replace target_signal with gdb_signal throughout. sim/common/ 2012-05-24 Pedro Alves <palves@redhat.com> PR gdb/7205 Replace target_signal with gdb_signal throughout.
Diffstat (limited to 'gdb/corelow.c')
-rw-r--r--gdb/corelow.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/gdb/corelow.c b/gdb/corelow.c
index aa344c67d9d..f566b2d89b2 100644
--- a/gdb/corelow.c
+++ b/gdb/corelow.c
@@ -440,17 +440,17 @@ core_open (char *filename, int from_tty)
siggy = bfd_core_file_failing_signal (core_bfd);
if (siggy > 0)
{
/* NOTE: target_signal_from_host() converts a target signal
value into gdb's internal signal value. Unfortunately gdb's
- internal value is called ``target_signal'' and this function
+ internal value is called ``gdb_signal'' and this function
got the name ..._from_host(). */
- enum target_signal sig = (core_gdbarch != NULL
- ? gdbarch_target_signal_from_host (core_gdbarch,
- siggy)
- : target_signal_from_host (siggy));
+ enum gdb_signal sig = (core_gdbarch != NULL
+ ? gdbarch_gdb_signal_from_host (core_gdbarch,
+ siggy)
+ : gdb_signal_from_host (siggy));
printf_filtered (_("Program terminated with signal %d, %s.\n"),
- siggy, target_signal_to_string (sig));
+ siggy, gdb_signal_to_string (sig));
}
/* Fetch all registers from core file. */
@@ -440,17 +440,17 @@ core_open (char *filename, int from_tty)
if (siggy > 0)
{
- /* NOTE: target_signal_from_host() converts a target signal
+ /* NOTE: gdb_signal_from_host() converts a target signal
value into gdb's internal signal value. Unfortunately gdb's